# see the URL below for information on how to write OpenStudio measures
# http://nrel.github.io/OpenStudio-user-documentation/reference/measure_writing_guide/

# start the measure
class EditSensibleHeatFractionOfPeople < OpenStudio::Ruleset::ModelUserScript

  # human readable name
  def name
    return "Edit Sensible Heat Fraction of People"
  end

  # human readable description
  def description
    return "This measure replaces the 'Sensible Heat Fraction of People' of all people in the model with values that you specify. This is useful for thermal comfort studies where the percentage of heat transferred to the air is important."
  end

  # human readable description of modeling approach
  def modeler_description
    return "This measure replaces the 'Sensible Heat Fraction of People' of all people in the model with values that you specify."
  end

  # define the arguments that the user will input
  def arguments(model)
    args = OpenStudio::Ruleset::OSArgumentVector.new

	#People Sensible Heat Fraction = Sensible/Total Ratio
	peopleSensFract = OpenStudio::Ruleset::OSArgument::makeDoubleArgument("peopleSensHeatFract",false)
	peopleSensFract.setDisplayName("People Sensible Heat Fraction")
	peopleSensFract.setDefaultValue(0.0)
	args << peopleSensFract

    return args
  end

  # define what happens when the measure is run
  def run(model, runner, user_arguments)
    super(model, runner, user_arguments)

    # use the built-in error checking
    if !runner.validateUserArguments(arguments(model), user_arguments)
      return false
    end

    # assign the user inputs to variables
	peopleSensFract = runner.getStringArgumentValue("peopleSensHeatFract", user_arguments).to_f
    # check the inputs for reasonableness
	if peopleSensFract < 0 or peopleSensFract > 1
      runner.registerError("PPeople Sensible Heat Fraction must be between 0 and 1.")
      return false
    end	
    # change the fraction radiant of all light and equipment objects in the model.
	peopleCount = 0
	space_types = model.getSpaceTypes
	space_types.each do |space_type|
		people = space_type.people
		people.each do |person|
			pdef = model.getPeople(person.handle).get
			finalDef = model.getPeopleDefinition(pdef.peopleDefinition.handle).get
			finalDef.setSensibleHeatFraction(peopleSensFract)
			peopleCount += 1
		end
	end

    # report final condition of model
	runner.registerFinalCondition("The building finished with #{peopleCount} people definitions with their sensible heat fraction set to #{peopleSensFract}.")
    return true

  end
  
end

# register the measure to be used by the application
EditSensibleHeatFractionOfPeople.new.registerWithApplication
